archive_read
------------

.. currentmodule:: eqcorrscan.utils.archive_read
.. automodule:: eqcorrscan.utils.archive_read

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       read_data

    .. comment to end block

    Private Functions
    -----------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       _check_available_data
       _get_station_file
